<html>
<head>
  <meta charset="UTF-8">
  <title>Graph</title>
  <link rel="stylesheet" href="font-awesome-4.7.0/css/font-awesome.min.css">
</head>
<body>
  <div id="graph">
  </div>
  <script src="dist/bundle.js"></script>
</body>
</html>